<?php

/*
  Plugin Name: Access Demo Importer
  Plugin URI: http://accesspressthemes.com/
  Description: Adds Demo import feature on welcome page
  Author: AccessPress Themes
  Author URI: http://accesspressthemes.com/
  Version: 1.0.0
  Text Domain: access-demo-importer
 */
//delete_option( 'sidebars_widgets' );

if ( !defined( 'ABSPATH' ) )
    exit;

if ( !class_exists( 'PDI_Importer' ) ) {

    class PDI_Importer {

        var $this_uri;
        var $this_dir;
        var $configFile;
        var $uploads_dir;

        /*
         * Constructor
         */

        public function __construct() {

            // This uri & dir
            $this->this_uri = plugin_dir_url( __FILE__ );
            $this->this_dir = plugin_dir_path( __FILE__ );

            $this->uploads_dir = wp_get_upload_dir();

            // Include necesarry files
            $this->configFile = include $this->this_dir . 'import_config.php';

            
            add_action('pdi_display_demos', array( $this, 'pdi_display_demos') );
            // Add necesary backend JS
            add_action( 'admin_enqueue_scripts', array( $this, 'load_backends' ) );

            // Actions for the ajax call
            add_action( 'wp_ajax_pdi_install_demo', array( $this, 'pdi_install_demo' ) );
            add_action( 'wp_ajax_nopriv_pdi_install_demo', array( $this, 'pdi_install_demo' ) );

            load_plugin_textdomain( 'access-demo-importer', false, basename( dirname( __FILE__ ) ) . '/lang' );
        }

       
        /*
         *  Display the available demos
         */

        function pdi_display_demos() {

            $theme = wp_get_theme();

            $return = '<div class="wrap">';

            if ( is_array( $this->configFile ) && !is_null( $this->configFile ) ) {
                $return .= '<div class="pdi-import-message">' . esc_html__( 'Click on the desired demo to install demo content and theme options setup.', 'access-demo-importer' ) . '</div>';
                $return .= '<div class="pdi-reset-database"><label class="pdi-switch"><input type="checkbox" name="resetall" id="resetall" value="true"><span class="pdi-slider round"></span></label>' . esc_html__( 'Reset WordPress Database? This will erase all content (posts, pages, etc) and install demo content.', 'access-demo-importer' ) . '</label></div>';
                $return .= '<div class="pdi-demo-wrap clearfix">';

                // Loop through demos
                foreach ( $this->configFile as $demo => $demoContent ) {
                    $return .= '<div class="pdi-demos">
              <img src="' . esc_url( trailingslashit( $this->this_uri ) . 'demo-data/screen/' . $demoContent[ 'demoImg' ] ) . '">
              <div class="demo-button-actions">
              <h4>' . esc_html( $demoContent[ 'demoName' ] ) . '</h4>
              <div class="demo-buttons">
              <a href="' . esc_url( $demoContent[ 'liveURL' ] ) . '" target="_blank" class="button">' . esc_html__( 'Preview', 'access-demo-importer' ) . '</a> 
              <a href="#" class="pdi-import-button button button-primary" data-install="' . esc_attr( $demo ) . '" data-reset="false">' . esc_html__( 'Install', 'access-demo-importer' ) . '</a>
              </div>
              </div>
              </div>';
                }

                $return .= '</div>';
            } else {
                $return .= '<p><div class="pdi-import-message">' . esc_html__( "It looks like the config file for the demos is missing or conatins errors!. Demo install can\'t go futher!", 'access-demo-importer' ) . '</div><p>';
            }
            $return .= '</div>';

            echo ($return);
        }

        /*
         *  Do the install on ajax call
         */

        function pdi_install_demo() {
            global $wpdb;
            $return = '';

            // Get the demo content from the right file
            $demo = $this->configFile[ $_POST[ 'demo' ] ];

            // Should we reset database?
            if ( isset( $_POST[ 'datareset' ] ) && $_POST[ 'datareset' ] == 'true' ) {
                if ( current_user_can( 'manage_options' ) ) {
                    $this->database_reset();
                }
            }

            if ( current_user_can( 'manage_options' ) ) {
                // Import XML content
                if ( isset( $demo[ 'xmlContentFile' ] ) ) {
                    $this->importDemoContent( $demo[ 'xmlContentFile' ] );
                }

                // Setup customizer options
                if ( isset( $demo[ 'customizerFile' ] ) ) {
                    $this->importCustomizer( $demo[ 'customizerFile' ] );
                }

                // Set menu
                if ( isset( $demo[ 'menuArray' ] ) ) {
                    $this->setMenu( $demo[ 'menuArray' ] );
                }

                // Setup theme options
                if ( isset( $demo[ 'themeOptionsFile' ] ) ) {
                    $this->importThemeOptions( $demo[ 'themeOptionsFile' ] );
                }

                // Setup theme options
                if ( isset( $demo[ 'widgetFile' ] ) ) {
                    $this->importWidgets( $demo[ 'widgetFile' ] );
                }
            }

            // Import Slider Revolution slides
            if ( $demo[ 'revSliderZipFiles' ] && is_array( $demo[ 'revSliderZipFiles' ] ) ) {
                $this->importSliderRev( $demo[ 'revSliderZipFiles' ] );
            }

            // this is required to return a proper result
            die();
        }

        /*
         * Reset the database, if the case
         */

        function database_reset() {
            global $wpdb;
            $options = array(
                'offset' => 0,
                'orderby' => 'post_date',
                'order' => 'DESC',
                'post_type' => 'post',
                'post_status' => 'publish'
            );

            $statuses = array( 'publish', 'future', 'draft', 'pending', 'private', 'trash', 'inherit', 'auto-draft', 'scheduled' );
            $types = array(
                'post',
                'page',
                'attachment',
                'nav_menu_item',
                'wpcf7_contact_form',
                'product',
                'portfolio',
                'testimonial',
                'team'
            );

            // delete posts
            foreach ( $types as $type ) {
                foreach ( $statuses as $status ) {
                    $options[ 'post_type' ] = $type;
                    $options[ 'post_status' ] = $status;

                    $posts = get_posts( $options );
                    $offset = 0;
                    while ( count( $posts ) > 0 ) {
                        if ( $offset == 10 ) {
                            break;
                        }
                        $offset++;
                        foreach ( $posts as $post ) {
                            wp_delete_post( $post->ID, true );
                        }
                        $posts = get_posts( $options );
                    }
                }
            }


            // Delete categories, tags, etc
            $taxonomies_array = array( 'category', 'post_tag', 'portfolio-category', 'testimonial-category', 'team-category', 'nav_menu', 'product_cat' );
            foreach ( $taxonomies_array as $tax ) {
                $cats = get_terms( $tax, array( 'hide_empty' => false, 'fields' => 'ids' ) );
                foreach ( $cats as $cat ) {
                    wp_delete_term( $cat, $tax );
                }
            }


            // Delete Slider Revolution Sliders
            if ( class_exists( 'RevSlider' ) ) {
                $sliderObj = new RevSlider();
                foreach ( $sliderObj->getArrSliders() as $slider ) {
                    $slider->initByID( $slider->getID() );
                    $slider->deleteSlider();
                }
            }

            // Delete Widgets
            global $wp_registered_widget_controls;

            $widget_controls = $wp_registered_widget_controls;

            $available_widgets = array();

            foreach ( $widget_controls as $widget ) {
                if ( !empty( $widget[ 'id_base' ] ) && !isset( $available_widgets[ $widget[ 'id_base' ] ] ) ) { // no dupes
                    $available_widgets[] = $widget[ 'id_base' ];
                }
            }

            update_option( 'sidebars_widgets', array( 'wp_inactive_widgets' => array() ) );
            foreach ( $available_widgets as $widget_data ) {
                update_option( 'widget_' . $widget_data, array() );
            }

            //Clear "uploads" folder
            $this->arwp_clear_uploads( $this->uploads_dir[ 'basedir' ] );
        }

        /**
         * Clear "uploads" folder
         * @param string $dir
         * @return bool
         */
        private function arwp_clear_uploads( $dir ) {
            $files = array_diff( scandir( $dir ), array( '.', '..' ) );
            foreach ( $files as $file ) {
                ( is_dir( "$dir/$file" ) ) ? $this->arwp_clear_uploads( "$dir/$file" ) : unlink( "$dir/$file" );
            }

            return ( $dir != $this->uploads_dir[ 'basedir' ] ) ? rmdir( $dir ) : true;
        }

        /*
         * Set the menu on theme location
         */

        function setMenu( $menuArray ) {

            if ( !$menuArray ) {
                return;
            }

            $locations = get_theme_mod( 'nav_menu_locations' );

            foreach ( $menuArray as $menuId => $menuname ) {
                $menu_exists = wp_get_nav_menu_object( $menuname );

                if ( !$menu_exists ) {
                    $term_id_of_menu = wp_create_nav_menu( $menuname );
                } else {
                    $term_id_of_menu = $menu_exists->term_id;
                }

                $locations[ $menuId ] = $term_id_of_menu;
            }

            set_theme_mod( 'nav_menu_locations', $locations );
        }

        /*
         * Import Slider Revolution
         */

        function importSliderRev( $slidersArray ) {
            if ( class_exists( 'RevSlider' ) ) {
                foreach ( $slidersArray as $slider ) {
                    // Get the zip file path
                    $sliderFile = $this->this_dir . 'demo-data/revSlider/' . $slider;
                    if ( file_exists( $sliderFile ) ) {
                        $slider = new RevSlider();
                        $slider->importSliderFromPost( true, true, $sliderFile );
                    }
                }
            } else {
                echo 'It looks like you don\'t have Slider Revolution installed and activated. Sliders were not imported!<br>';
            }
        }

        /*
         * Import demo XML content
         */

        function importDemoContent( $demoXml ) {

            if ( !defined( 'WP_LOAD_IMPORTERS' ) )
                define( 'WP_LOAD_IMPORTERS', true );

            if ( !class_exists( 'WP_Import' ) ) {
                $class_wp_importer = $this->this_dir . "wordpress-importer.php";
                if ( file_exists( $class_wp_importer ) )
                    require $class_wp_importer;
            }

            // Import demo content from XML
            if ( class_exists( 'WP_Import' ) ) {
                $import_filepath = $this->this_dir . 'demo-data/content/' . $demoXml; // Get the xml file from directory 

                $wp_import = new WP_Import();
                $wp_import->fetch_attachments = true;
                $wp_import->import( $import_filepath );

                // Import DONE
                // set homepage as front page
                $page = get_page_by_path( 'front-page' );
                if ( $page ) {
                    update_option( 'show_on_front', 'page' );
                    update_option( 'page_on_front', $page->ID );
                } else {
                    $page = get_page_by_title( 'Home' );
                    if ( $page ) {
                        update_option( 'show_on_front', 'page' );
                        update_option( 'page_on_front', $page->ID );
                    }
                }

                $blog = get_page_by_path( 'blogs' );
                if ( $blog ) {
                    update_option( 'show_on_front', 'page' );
                    update_option( 'page_for_posts', $blog->ID );
                }
            }
        }

        /*
         * Import Theme Options
         */

        function importThemeOptions( $themeOptionsFile ) {
            $themeoption_filepath = $this->this_uri . 'demo-data/themeOptions/' . $themeOptionsFile;

            $json_file = wp_remote_get( $themeoption_filepath );
            if ( $json_file[ 'response' ][ 'code' ] == '200' && !empty( $json_file[ 'body' ] ) ) {
                if ( update_option( 'punte_options', json_decode( $json_file[ 'body' ], true ), '', 'yes' ) ) {
                    echo esc_html__( 'Theme Options saved.', 'access-demo-importer' ) . '<br>';
                }
            } else {
                echo esc_html__( 'Theme Options could not be imported', 'access-demo-importer' ) . '<br>';
            }
        }

        /*
         * Import Customizer Options
         */

        function importCustomizer( $customizerFile ) {
            $customizer_filepath = $this->this_dir . 'demo-data/customizer/' . $customizerFile;

            if ( file_exists( $customizer_filepath ) ) {
                $customizer_file = file_get_contents( $customizer_filepath, true );
                if ( !empty( $customizer_file ) ) {
                    $options = unserialize( $customizer_file );
                    // Loop through the mods.
                    foreach ( $options[ 'mods' ] as $key => $val ) {

                        // Save the mod.
                        set_theme_mod( $key, $val );
                    }
                    echo esc_html__( 'Customizer Settings saved.', 'access-demo-importer' ) . '<br>';
                } else {
                    echo esc_html__( 'Customizer Settings could not be imported', 'access-demo-importer' ) . '<br>';
                }
            } else {
                echo esc_html__( 'Customizer Settings file not found.', 'access-demo-importer' ) . '<br>';
            }
        }

        /*
         * Import Widgets Options
         */

        function ImportWidgets( $widgetFile ) {
            $widget_filepath = $this->this_dir . 'demo-data/widget/' . $widgetFile;
            if ( file_exists( $widget_filepath ) ) {
                global $wp_registered_sidebars;

                $widget_file = file_get_contents( $widget_filepath, true );
                $data = json_decode( $widget_file );
                // Have valid data?
                // If no data or could not decode
                if ( empty( $data ) || !is_object( $data ) ) {
                    wp_die(
                            _e( 'Widget data is not available', IDM_TD ), '', array( 'back_link' => true )
                    );
                }

                global $wp_registered_widget_controls;

                $widget_controls = $wp_registered_widget_controls;

                $available_widgets = array();

                foreach ( $widget_controls as $widget ) {

                    if ( !empty( $widget[ 'id_base' ] ) && !isset( $available_widgets[ $widget[ 'id_base' ] ] ) ) { // no dupes
                        $available_widgets[ $widget[ 'id_base' ] ][ 'id_base' ] = $widget[ 'id_base' ];
                        $available_widgets[ $widget[ 'id_base' ] ][ 'name' ] = $widget[ 'name' ];
                    }
                }

                // Get all existing widget instances
                $widget_instances = array();
                foreach ( $available_widgets as $widget_data ) {
                    $widget_instances[ $widget_data[ 'id_base' ] ] = get_option( 'widget_' . $widget_data[ 'id_base' ] );
                }

                // Begin results
                $results = array();

                // Loop import data's sidebars
                foreach ( $data as $sidebar_id => $widgets ) {

                    // Skip inactive widgets
                    // (should not be in export file)
                    if ( 'wp_inactive_widgets' == $sidebar_id ) {
                        continue;
                    }

                    // Check if sidebar is available on this site
                    // Otherwise add widgets to inactive, and say so
                    if ( isset( $wp_registered_sidebars[ $sidebar_id ] ) ) {
                        $sidebar_available = true;
                        $use_sidebar_id = $sidebar_id;
                        $sidebar_message_type = 'success';
                        $sidebar_message = '';
                    } else {
                        $sidebar_available = false;
                        $use_sidebar_id = 'wp_inactive_widgets'; // add to inactive if sidebar does not exist in theme
                        $sidebar_message_type = 'error';
                        $sidebar_message = _e( 'Widget area does not exist in theme (using Inactive)', IDM_TD );
                    }

                    // Result for sidebar
                    $results[ $sidebar_id ][ 'name' ] = !empty( $wp_registered_sidebars[ $sidebar_id ][ 'name' ] ) ? $wp_registered_sidebars[ $sidebar_id ][ 'name' ] : $sidebar_id; // sidebar name if theme supports it; otherwise ID
                    $results[ $sidebar_id ][ 'message_type' ] = $sidebar_message_type;
                    $results[ $sidebar_id ][ 'message' ] = $sidebar_message;
                    $results[ $sidebar_id ][ 'widgets' ] = array();

                    // Loop widgets
                    foreach ( $widgets as $widget_instance_id => $widget ) {

                        $fail = false;

                        // Get id_base (remove -# from end) and instance ID number
                        $id_base = preg_replace( '/-[0-9]+$/', '', $widget_instance_id );
                        $instance_id_number = str_replace( $id_base . '-', '', $widget_instance_id );

                        // Does site support this widget?
                        if ( !$fail && !isset( $available_widgets[ $id_base ] ) ) {
                            $fail = true;
                            $widget_message_type = 'error';
                            $widget_message = __( 'Site does not support widget', IDM_TD ); // explain why widget not imported
                        }

                        // Filter to modify settings object before conversion to array and import
                        // Leave this filter here for backwards compatibility with manipulating objects (before conversion to array below)
                        // Ideally the newer wie_widget_settings_array below will be used instead of this
                        $widget = apply_filters( 'wie_widget_settings', $widget ); // object
                        // Convert multidimensional objects to multidimensional arrays
                        // Some plugins like Jetpack Widget Visibility store settings as multidimensional arrays
                        // Without this, they are imported as objects and cause fatal error on Widgets page
                        // If this creates problems for plugins that do actually intend settings in objects then may need to consider other approach: https://wordpress.org/support/topic/problem-with-array-of-arrays
                        // It is probably much more likely that arrays are used than objects, however
                        $widget = json_decode( wp_json_encode( $widget ), true );

                        // Filter to modify settings array
                        // This is preferred over the older wie_widget_settings filter above
                        // Do before identical check because changes may make it identical to end result (such as URL replacements)
                        $widget = apply_filters( 'wie_widget_settings_array', $widget );

                        // Does widget with identical settings already exist in same sidebar?
                        if ( !$fail && isset( $widget_instances[ $id_base ] ) ) {

                            // Get existing widgets in this sidebar
                            $sidebars_widgets = get_option( 'sidebars_widgets' );
                            $sidebar_widgets = isset( $sidebars_widgets[ $use_sidebar_id ] ) ? $sidebars_widgets[ $use_sidebar_id ] : array(); // check Inactive if that's where will go
                            // Loop widgets with ID base
                            $single_widget_instances = !empty( $widget_instances[ $id_base ] ) ? $widget_instances[ $id_base ] : array();
                            foreach ( $single_widget_instances as $check_id => $check_widget ) {

                                // Is widget in same sidebar and has identical settings?
                                if ( in_array( "$id_base-$check_id", $sidebar_widgets ) && ( array ) $widget == $check_widget ) {

                                    $fail = true;
                                    $widget_message_type = 'warning';
                                    $widget_message = __( 'Widget already exists', IDM_TD ); // explain why widget not imported

                                    break;
                                }
                            }
                        }

                        // No failure
                        if ( !$fail ) {

                            // Add widget instance
                            $single_widget_instances = get_option( 'widget_' . $id_base ); // all instances for that widget ID base, get fresh every time
                            $single_widget_instances = !empty( $single_widget_instances ) ? $single_widget_instances : array( '_multiwidget' => 1 ); // start fresh if have to
                            $single_widget_instances[] = $widget; // add it
                            // Get the key it was given
                            end( $single_widget_instances );
                            $new_instance_id_number = key( $single_widget_instances );

                            // If key is 0, make it 1
                            // When 0, an issue can occur where adding a widget causes data from other widget to load, and the widget doesn't stick (reload wipes it)
                            if ( '0' === strval( $new_instance_id_number ) ) {
                                $new_instance_id_number = 1;
                                $single_widget_instances[ $new_instance_id_number ] = $single_widget_instances[ 0 ];
                                unset( $single_widget_instances[ 0 ] );
                            }

                            // Move _multiwidget to end of array for uniformity
                            if ( isset( $single_widget_instances[ '_multiwidget' ] ) ) {
                                $multiwidget = $single_widget_instances[ '_multiwidget' ];
                                unset( $single_widget_instances[ '_multiwidget' ] );
                                $single_widget_instances[ '_multiwidget' ] = $multiwidget;
                            }

                            // Update option with new widget
                            update_option( 'widget_' . $id_base, $single_widget_instances );

                            // Assign widget instance to sidebar
                            $sidebars_widgets = get_option( 'sidebars_widgets' ); // which sidebars have which widgets, get fresh every time
                            // Avoid rarely fatal error when the option is an empty string
                            // https://github.com/churchthemes/widget-importer-exporter/pull/11
                            if ( !$sidebars_widgets ) {
                                $sidebars_widgets = array();
                            }

                            $new_instance_id = $id_base . '-' . $new_instance_id_number; // use ID number from new widget instance
                            $sidebars_widgets[ $use_sidebar_id ][] = $new_instance_id; // add new instance to sidebar

                            update_option( 'sidebars_widgets', $sidebars_widgets ); // save the amended data
                            // After widget import action
                            $after_widget_import = array(
                                'sidebar' => $use_sidebar_id,
                                'sidebar_old' => $sidebar_id,
                                'widget' => $widget,
                                'widget_type' => $id_base,
                                'widget_id' => $new_instance_id,
                                'widget_id_old' => $widget_instance_id,
                                'widget_id_num' => $new_instance_id_number,
                                'widget_id_num_old' => $instance_id_number
                            );
                            do_action( 'wie_after_widget_import', $after_widget_import );

                            // Success message
                            if ( $sidebar_available ) {
                                $widget_message_type = 'success';
                                $widget_message = esc_html__( 'Imported', IDM_TD );
                            } else {
                                $widget_message_type = 'warning';
                                $widget_message = esc_html__( 'Imported to Inactive', IDM_TD );
                            }
                        }

                        // Result for widget instance
                        $results[ $sidebar_id ][ 'widgets' ][ $widget_instance_id ][ 'name' ] = isset( $available_widgets[ $id_base ][ 'name' ] ) ? $available_widgets[ $id_base ][ 'name' ] : $id_base; // widget name or ID if name not available (not supported by site)
                        $results[ $sidebar_id ][ 'widgets' ][ $widget_instance_id ][ 'title' ] = !empty( $widget[ 'title' ] ) ? $widget[ 'title' ] : esc_html__( 'No Title', IDM_TD ); // show "No Title" if widget instance is untitled
                        $results[ $sidebar_id ][ 'widgets' ][ $widget_instance_id ][ 'message_type' ] = $widget_message_type;
                        $results[ $sidebar_id ][ 'widgets' ][ $widget_instance_id ][ 'message' ] = $widget_message;
                    }
                }
                /*
                  ?>
                  <table id="wie-import-results">

                  <?php
                  // Loop sidebars.
                  foreach ( $results as $sidebar ) :
                  ?>

                  <tr class="wie-import-results-sidebar">
                  <td colspan="2" class="wie-import-results-sidebar-name">
                  <?php
                  // Sidebar name if theme supports it; otherwise ID.
                  echo esc_html( $sidebar[ 'name' ] );
                  ?>
                  </td>
                  <td class="wie-import-results-sidebar-message wie-import-results-message wie-import-results-message-<?php echo esc_attr( $sidebar[ 'message_type' ] ); ?>">
                  <?php
                  // Sidebar may not exist in theme.
                  echo esc_html( $sidebar[ 'message' ] );
                  ?>
                  </td>
                  </tr>

                  <?php
                  // Loop widgets.
                  foreach ( $sidebar[ 'widgets' ] as $widget ) :
                  ?>

                  <tr class="wie-import-results-widget">
                  <td class="wie-import-results-widget-name">
                  <?php
                  // Widget name or ID if name not available (not supported by site).
                  echo esc_html( $widget[ 'name' ] );
                  ?>
                  </td>
                  <td class="wie-import-results-widget-title">
                  <?php
                  // Shows "No Title" if widget instance is untitled.
                  echo esc_html( $widget[ 'title' ] );
                  ?>
                  </td>
                  <td class="wie-import-results-widget-message wie-import-results-message wie-import-results-message-<?php echo esc_attr( $widget[ 'message_type' ] ); ?>">
                  <?php
                  // Sidebar may not exist in theme.
                  echo esc_html( $widget[ 'message' ] );
                  ?>
                  </td>
                  </tr>

                  <?php endforeach; ?>

                  <tr class="wie-import-results-space">
                  <td colspan="100%"></td>
                  </tr>

                  <?php endforeach; ?>

                  </table>
                  <?php
                 */
            } else {
                echo esc_html__( 'Widget Importer file not found.', 'access-demo-importer' ) . '<br>';
            }
        }

        /*
          Register necessary backend js
         */

        function load_backends() {
            wp_enqueue_script( 'pdi-demo-ajax', $this->this_uri . 'demo-ajax.js', array( 'jquery' ), '2.0.0', true );
            wp_localize_script( 'pdi-demo-ajax', 'this_dir', $this->this_uri );
            wp_enqueue_style( 'pdi-demo-style', $this->this_uri . 'demo-style.css', array(), '2.0.0' );
        }

    }

}
new PDI_Importer;
